==> dde-session-shell_5.5.34.tar.xz: BUILD/translations/dde-session-shell_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="348"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>این برنامه‌ها مانع از خاموش شدن کامپیوتر می‌شوند و اجبار به خاموش کردن ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="349"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="354"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>برای بستن برنامه ، روی لغو کلیک کرده و سپس برنامه را ببندید.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="353"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>این برنامه‌ها مانع از راه اندازی مجدد کامپیوتر می‌شوند و اجبار به راه اندازی مجدد  ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>این برنامه‌ها مانع از تعلیق  کامپیوتر می‌شوند و اجبار به تعلیق  ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="361"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>این برنامه‌ها مانع از هایبرنت کامپیوتر می‌شوند و اجبار به  هایبرنت ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="365"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>این برنامه‌ها مانع از خروج کامپیوتر می‌شوند و اجبار به خروج ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="382"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="423"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="445"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="593"/>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="385"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="425"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="448"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="596"/>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="388"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="599"/>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="390"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="602"/>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="392"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="451"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="608"/>
        <source>Log out</source>
        <translation>خارج شدن از حساب کاربری</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="446"/>
        <source>Are you sure you want to shut down?</source>
        <translation>آیا از خاموشی مطمئن هستید ؟</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="449"/>
        <source>Are you sure you want to reboot?</source>
        <translation>آیا از  راه اندازی مجدد مطمئن هستید ؟</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="452"/>
        <source>Are you sure you want to log out?</source>
        <translation>آیا از خارج شدن مطمئن هستید ؟</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="605"/>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="612"/>
        <source>Switch user</source>
        <translation>تغییر حساب کاربری</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="327"/>
        <source>Wrong Password</source>
        <translation>رمزعبور اشتباه است</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="331"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="353"/>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="357"/>
        <source>Failed to lock screen</source>
        <translation>قفل صفحه انجام نشد</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="229"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>تایید اثر انگشت منقضی شد , لطفا ً رمزعبور خود را دستی وارد کنید</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="247"/>
        <source>Failed to match fingerprint</source>
        <translation>تطابق اثر انگشت ناموفق بود</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="278"/>
        <source>Wrong Password</source>
        <translation>رمزعبور اشتباه است</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="129"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>کاربران بالا هنوز  داخل  سیستم هستند و داده‌ها به دلیل خاموش شدن از دست خواهند رفت , آیا مطمئنید که می‌خواهید سیستم خاموش شود ؟</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>کاربران بالا هنوز  داخل  سیستم هستند و داده‌ها به دلیل راه اندازی مجدد از دست خواهند رفت , آیا مطمئنید که می‌خواهید سیستم راه اندازی مجدد شود ؟</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="29"/>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="101"/>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="108"/>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="115"/>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>آغاز پایش سیستم</translation>
    </message>
</context>
<context>
    <name>UserExpiredWidget</name>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="149"/>
        <source>Password expired, please change</source>
        <translation>رمز عبور منقضی شده است ، لطفا آن را عوض کنید</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="153"/>
        <source>New password</source>
        <translation>رمز عبور جدید</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="163"/>
        <source>Repeat password</source>
        <translation>تکرار رمزعبور</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="322"/>
        <source>Failed to change your password</source>
        <translation>تغییر رمز عبور انجام نشد</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="336"/>
        <source>Password too weak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="344"/>
        <source>Please enter the new password</source>
        <translation>لطفا رمز عبور جدید را وارد کنید</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="350"/>
        <source>Please repeat the new password</source>
        <translation>لطفا رمز عبور جدید دوباره را وارد کنید</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="356"/>
        <source>Passwords do not match</source>
        <translation>گذرواژه ها یکسان نیستند.</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="195"/>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="199"/>
        <source>Account</source>
        <translation>حساب کاربری</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="241"/>
        <source>Please enter the account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="248"/>
        <source>Please enter the password</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="328"/>
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fa">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>رمزعبور اشتباه است</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>حساب کاربری</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation>رمز عبور قدیم</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>رمز عبور جدید</translation>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>گذرواژه ها یکسان نیستند.</translation>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>رمزعبور جدید باید با رمز فعلی متفاوت باشد</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>رمزعبور اشتباه</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>طرح بندی صفحه کلید</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>منبع قدرت</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>رمزعبور اشتباه است</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>قفل صفحه انجام نشد</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>تایید اثر انگشت منقضی شد , لطفا ً رمزعبور خود را دستی وارد کنید</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>تطابق اثر انگشت ناموفق بود</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>کاربران بالا هنوز  داخل  سیستم هستند و داده‌ها به دلیل خاموش شدن از دست خواهند رفت , آیا مطمئنید که می‌خواهید سیستم خاموش شود ؟</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>کاربران بالا هنوز  داخل  سیستم هستند و داده‌ها به دلیل راه اندازی مجدد از دست خواهند رفت , آیا مطمئنید که می‌خواهید سیستم راه اندازی مجدد شود ؟</translation>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>ضعیف</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>متوسط</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation>جایگاه رمزعبور نمی تواند خالی باشد.</translation>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation>رمز عبور  که کمتر از  %1 نویسه نباید باشد</translation>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>خارج شدن از حساب کاربری</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation>تغییر حساب کاربری</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>آغاز پایش سیستم</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Administrator</source>
        <translation>مدیر</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>روی صفحه</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>این برنامه‌ها مانع از خاموش شدن کامپیوتر می‌شوند و اجبار به خاموش کردن ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>برای بستن برنامه ، روی لغو کلیک کرده و سپس برنامه را ببندید.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>این برنامه‌ها مانع از راه اندازی مجدد کامپیوتر می‌شوند و اجبار به راه اندازی مجدد  ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>این برنامه‌ها مانع از تعلیق  کامپیوتر می‌شوند و اجبار به تعلیق  ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>این برنامه‌ها مانع از هایبرنت کامپیوتر می‌شوند و اجبار به  هایبرنت ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>این برنامه‌ها مانع از خروج کامپیوتر می‌شوند و اجبار به خروج ممکن است باعث از دست رفتن داده‌ها شود .</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>خاموش شدن</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>راه اندازی مجدد</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>معلق کردن</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>هایبرنت</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>خارج شدن از حساب کاربری</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>آیا از خاموشی مطمئن هستید ؟</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>آیا از  راه اندازی مجدد مطمئن هستید ؟</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>آیا از خارج شدن مطمئن هستید ؟</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>روشن کردن</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>خاموش کردن</translation>
    </message>
</context>
</TS>
